<p align="center">

<p align="center">
   <img width="50%" height="40%" src="" alt="Logo">
  </p>

  <h1 align="center">tselai</h1>
  <p align="center">
  <strong>LLM support in SQLite</strong>
    <br> <br />
    <a href="#status"><strong> Status</strong></a> |
    <a href="#why"><strong> Why</strong></a> |
    <a href="#how"><strong> How </strong></a> |
    <a href="#installation"><strong> Installation </strong></a> |
    <a href="#usage"><strong> Usage </strong></a> |
    <a href="#roadmap"><strong> Roadmap </strong></a> 

   </p>
<p align="center">

<p align="center">
<a href="https://pypi.org/project/tselai/"><img src="https://img.shields.io/pypi/v/tselai?label=PyPI"></a>
<a href="https://github.com/Florents-Tselai/tselai/actions/workflows/test.yml?branch=mainline"><img src="https://github.com/Florents-Tselai/tselai/actions/workflows/test.yml/badge.svg"></a>
<a href="https://codecov.io/gh/Florents-Tselai/tselai"><img src="https://codecov.io/gh/Florents-Tselai/tselai/branch/main/graph/badge.svg"></a>  
<a href="https://opensource.org/licenses/BSD license"><img src="https://img.shields.io/badge/BSD license.0-blue.svg"></a>
<a href="https://github.com/Florents-Tselai/tselai/releases"><img src="https://img.shields.io/github/v/release/Florents-Tselai/tselai?include_prereleases&label=changelog"></a>

## Status

## Why

## How


## Installation

## Usage

```bash
pip install tselai
```

### Development

```bash
pip install -e '.[test]'
pytest
```

